# generated by datamodel-codegen:
#   filename:  schema.json
#   timestamp: 2023-03-11T12:30:23+00:00

from __future__ import annotations

from enum import Enum
from typing import List, Optional

from pydantic import BaseModel, constr


class Tag(BaseModel):
    name: constr(regex=r'^@')
    line: Optional[int] = None


class Status(Enum):
    passed = 'passed'
    Passed = 'Passed'
    PASSED = 'PASSED'
    failed = 'failed'
    Failed = 'Failed'
    FAILED = 'FAILED'
    undefined = 'undefined'
    Undefined = 'Undefined'
    UNDEFINED = 'UNDEFINED'
    skipped = 'skipped'
    Skipped = 'Skipped'
    SKIPPED = 'SKIPPED'
    pending = 'pending'
    Pending = 'Pending'
    PENDING = 'PENDING'
    ambiguous = 'ambiguous'
    Ambiguous = 'Ambiguous'
    AMBIGUOUS = 'AMBIGUOUS'


class Result(BaseModel):
    status: Status
    duration: Optional[float] = None
    error_message: Optional[str] = None


class Step(BaseModel):
    keyword: str
    line: Optional[int] = None
    name: Optional[str] = None
    hidden: Optional[bool] = None
    result: Optional[Result] = None


class Element(BaseModel):
    keyword: Optional[str] = None
    type: str
    id: Optional[str] = None
    line: int
    name: str
    tags: Optional[List[Tag]] = None
    steps: Optional[List[Step]] = None


class Feature(BaseModel):
    uri: str
    name: str
    description: str = None
    keyword: Optional[str] = None
    tags: Optional[List[Tag]] = None
    elements: Optional[List[Element]] = None


class Model(BaseModel):
    __root__: List[Feature]



from enum import Enum
from typing import List
from pydantic import BaseModel
from cujirax.xray import Endpoint, login, post


class Status(str, Enum):
    PASSED = "PASSED"
    EXECUTING = "EXECUTING"
    FAILED = "FAILED"
    BLOCKED = "BLOCKED"
    OUTOFSCOPE = "OUT-OF-SCOPE"
    DEFERRED = "DEFERRED"
    TODO = "TO DO"


class Info(BaseModel):
    summary: str
    description: str
    testPlanKey: str = None
    testEnvironments: List[str] = None
    version: str = None
    user: str = None
    revision: str = None
    startDate: str = None
    finishDate: str = None


class Evidence(BaseModel):
    data: str
    filename: str
    contentType: str


class Step(BaseModel):
    status: Status
    comment: str = None
    actualResult: str = None
    evidences: List[Evidence] = None

    def to_dict(self):
        return {
            "status": self.status.value,
            "comment": self.comment,
            "actualResult": self.actualResult,
            "evidences": self.evidences
        }


class Test(BaseModel):
    testKey: str
    status: str
    actualResult: str = None
    start: str = None
    finish: str = None
    evidence: List[Evidence] = None
    examples: List[str] = None
    steps: List[Step] = None
    defects: List[str] = None


class RequestBody(BaseModel):
    info: Info
    tests: List[Test]
    testExecutionKey: str = None


def import_xray_json_results(requestBody: RequestBody):
    header = login()
    response = post(
        endpoint=Endpoint.IMPORT_XRAY_JSON_RESULTS.value,
        payload=requestBody,
        headers=header
    )
    return response
